/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.layout.content.page.editor.internal.listener;

import com.liferay.layout.content.page.editor.listener.ContentPageEditorListener;
import com.liferay.layout.content.page.editor.listener.ContentPageEditorListenerTracker;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;

/**
 * @author Eudaldo Alonso
 */
@Component(immediate = true, service = ContentPageEditorListenerTracker.class)
public class ContentPageEditorListenerTrackerImpl
	implements ContentPageEditorListenerTracker {

	@Override
	public List<ContentPageEditorListener> getContentPageEditorListeners() {
		return new ArrayList<>(_contentPageEditorListeners);
	}

	@Reference(
		cardinality = ReferenceCardinality.MULTIPLE,
		policy = ReferencePolicy.DYNAMIC
	)
	protected void setContentPageEditorListener(
		ContentPageEditorListener contentPageEditorListener) {

		_contentPageEditorListeners.add(contentPageEditorListener);
	}

	protected void unsetContentPageEditorListener(
		ContentPageEditorListener contentPageEditorListener) {

		_contentPageEditorListeners.remove(contentPageEditorListener);
	}

	private final List<ContentPageEditorListener> _contentPageEditorListeners =
		new CopyOnWriteArrayList<>();

}